<?php
/**
 * EduMag Pro Featured category Customizer options
 *
 * @package Theme Palace
 * @subpackage EduMag Pro
 * @since EduMag Pro 1.0
 */

// Add featured post enable section
$wp_customize->add_section( 'edumag_pro_featured_category_section', array(
	'title'             => esc_html__( 'Featured Category','edumag-pro'),
	'description'       => esc_html__( 'Featured category section options.', 'edumag-pro' ),
	'panel'             => 'edumag_pro_sections_panel'
) );

// Add category blog enable setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[featured_category_enable]', array(
	'default'           => $options['featured_category_enable'],
	'sanitize_callback' => 'edumag_pro_sanitize_select'
) );

$wp_customize->add_control( 'edumag_pro_theme_options[featured_category_enable]', array(
	'label'             => esc_html__( 'Enable on', 'edumag-pro' ),
	'section'           => 'edumag_pro_featured_category_section',
	'type'              => 'select',
	'choices'           => edumag_pro_enable_disable_options()
) );

// Add category blog content type setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[featured_category_content_type]', array(
	'default'           => $options['featured_category_content_type'],
	'sanitize_callback' => 'edumag_pro_sanitize_select'
) );

$wp_customize->add_control( 'edumag_pro_theme_options[featured_category_content_type]', array(
	'label'           	=> esc_html__( 'Content Type', 'edumag-pro' ),
	'section'         	=> 'edumag_pro_featured_category_section',
	'type'            	=> 'select',
	'active_callback' 	=> 'edumag_pro_is_featured_category_section_active',
	'choices'         	=> array(
		'demo'     => esc_html__( 'Demo', 'edumag-pro' ),
        'category' => esc_html__( 'Category', 'edumag-pro' ),
        'posts'    => esc_html__( 'Posts', 'edumag-pro' ),
    ),
) );

for( $i=1; $i<=4; $i++ ){
	/**
 	 * Content type: post
	 */ 
	
	// Add setting and controls to input post id

	$wp_customize->add_setting( 'edumag_pro_theme_options[featured_category_content_posts_'. $i .']', array(
		'sanitize_callback' => 'edumag_pro_sanitize_number_range',
	) );

	$wp_customize->add_control( 'edumag_pro_theme_options[featured_category_content_posts_'. $i .']', array(
		'label'           => sprintf( esc_html__( 'Enter Post ID #%s', 'edumag-pro' ), $i ),
		'section'         => 'edumag_pro_featured_category_section',
		'input_attrs' 		=> array( 
			'style' 		=> 'width: 100px;',
			'min'			=> '1', 
			'placeholder'	=> esc_attr__( 'Post ID', 'edumag-pro' ),
			),
		'type'              => 'number',
		'active_callback' => 'edumag_pro_featured_category_content_post_active',
	) );

	/**
 	 * Content type: Catgory
	 */ 

	// Show category type setting and control
	$wp_customize->add_setting( 'edumag_pro_theme_options[featured_category_content_category_'. $i .']', array(
		'sanitize_callback' => 'edumag_pro_sanitize_dropdown_category_list'
	) );

	$wp_customize->add_control( new Edumag_Pro_Dropdown_Category_Control( $wp_customize, 'edumag_pro_theme_options[featured_category_content_category_'. $i .']', array(
		'label'           => sprintf( esc_html__( 'Select Category #%s', 'edumag-pro' ), $i ),
		'description'     => esc_html__( 'Only top post from selected category will be shown.', 'edumag-pro' ),
		'section'         => 'edumag_pro_featured_category_section',
		'active_callback' => 'edumag_pro_featured_category_content_category_active',
	) ) );
}