<?php
/**
 * Theme_Palace custom helper funtions
 *
 * This is the template that includes all the other files for core featured of Photo Fusion Pro
 *
 * @package Theme Palace
 * @subpackage EduMag Pro
 * @since EduMag Pro 1.0
 */

if( ! function_exists( 'edumag_pro_check_enable_status' ) ):
	/**
	 * Check status of content.
	 *
	 * @since EduMag Pro 1.0
	 */
  	function edumag_pro_check_enable_status( $input, $content_enable ){
		$options = edumag_pro_get_theme_options();

		// Content status.
		$content_status = $options[ $content_enable ];

		// Get Page ID outside Loop.
		$query_obj = get_queried_object();
		$page_id   = null;

	    if ( is_object( $query_obj ) && 'WP_Post' == get_class( $query_obj ) ) {
	    	$page_id = get_queried_object_id();
	    }

		if ( ( ! is_home() && is_front_page() ) && ( 'static-frontpage' === $content_status ) ) {
			$input = true;
		} else {
			$input = false;
		}

		return ( $input );
  	}
endif;
add_filter( 'edumag_pro_section_status', 'edumag_pro_check_enable_status', 10, 2 );


if ( ! function_exists( 'edumag_pro_is_sidebar_enable' ) ) :
	/**
	 * Check if sidebar is enabled in meta box first then in customizer
	 *
	 * @since EduMag Pro 1.0
	 */
	function edumag_pro_is_sidebar_enable() {
		$options          = edumag_pro_get_theme_options();
		$sidebar_position = $options['sidebar_position'];

        if ( is_home() ) {
            $post_id = get_option( 'page_for_posts' );
            if ( ! empty( $post_id ) )
                $post_sidebar_position = get_post_meta( $post_id, 'edumag-pro-sidebar-position', true );
            else
                $post_sidebar_position = '';
        } elseif ( is_archive() || is_search() ) {
            $post_sidebar_position = '';
        } else {
            $post_id = get_the_id();
            $post_sidebar_position = get_post_meta( $post_id, 'edumag-pro-sidebar-position', true );
        }

        if ( ( $sidebar_position == 'no-sidebar' && $post_sidebar_position == "" ) || $post_sidebar_position == 'no-sidebar' ) {
            return false;
        } else {
            return true;
        }
	}
endif;


if ( ! function_exists( 'edumag_pro_is_frontpage_content_enable' ) ) :
	/**
	 * Check home page ( static ) content status.
	 *
	 *.0
	 *
	 * @param bool $status Home page content status.
	 * @return bool Modified home page content status.
	 */
	function edumag_pro_is_frontpage_content_enable( $status ) {
		if ( is_front_page() ) {
			$options = edumag_pro_get_theme_options();
			$front_page_content_status = $options['enable_frontpage_content'];
			if ( false === $front_page_content_status ) {
				$status = false;
			}
		}
		return $status;
	}
endif;
add_filter( 'edumag_pro_filter_frontpage_content_enable', 'edumag_pro_is_frontpage_content_enable' );



if ( ! function_exists( 'edumag_pro_simple_breadcrumb' ) ) :
	/**
	 * Simple breadcrumb.
	 *
	 *
	 * @param  array $args Arguments
	 */
	function edumag_pro_simple_breadcrumb( $args = array() ) {

		/**
		 * Add breadcrumb.
		 *
		 */
		$options = edumag_pro_get_theme_options();
		// Bail if Breadcrumb disabled.
		$breadcrumb = $options['breadcrumb_enable'];
		if ( false === $breadcrumb ) {
			return;
		}

		$args = array(
			'show_on_front'   => false,
			'show_title'      => true,
			'show_browse'     => false,
		);
		breadcrumb_trail( $args );      

		return;
	}
endif;
add_action( 'edumag_pro_simple_breadcrumb', 'edumag_pro_simple_breadcrumb' , 10 );


if ( ! function_exists( 'edumag_pro_pagination' ) ) :
	/**
	 * pagination.
	 *
	 * @since EduMag Pro 1.0
	 */
	function edumag_pro_pagination() {
		$options = edumag_pro_get_theme_options();
		if ( true == $options['pagination_enable'] ) {
			$pagination = $options['pagination_type'];
			if ( $pagination == 'default' ) :
				the_posts_navigation();
			elseif ( $pagination == 'numeric' ) :
				the_posts_pagination( array(
				    'mid_size' => 4,
				    'prev_text' => __( 'Previous Posts', 'edumag-pro' ),
				    'next_text' => __( 'Next Posts', 'edumag-pro' ),
				) );
			endif;
		}
	}
endif;
add_action( 'edumag_pro_action_pagination', 'edumag_pro_pagination', 10 );


if ( ! function_exists( 'edumag_pro_post_pagination' ) ) :

	/**
	 * post pagination.
	 *
	 * @since EduMag Pro 1.0
	 */
	function edumag_pro_post_pagination() {
		the_post_navigation();
	}
endif;
add_action( 'edumag_pro_action_post_pagination', 'edumag_pro_post_pagination', 10 );

if( !function_exists( 'edumag_pro_excerpt_length' ) ):
	/**
	 * long excerpt
	 * 
	 * @since EduMag Pro 1.0
	 * @return  long excerpt value
	 */
	function edumag_pro_excerpt_length( $length ){
		if( is_admin() ) 
			return $length;

		$options = edumag_pro_get_theme_options();
		$length = $options['long_excerpt_length'];
		return $length;
	}
endif;

if( !function_exists( 'edumag_pro_custom_excerpt' ) ) :
	/**
	 * create the custom excerpts callback
	 *
	 * @since EduMag Pro 1.0
	 * @return  custom excerpts callback
	 */
	function edumag_pro_custom_excerpt( $length_callback = '', $more_callback = '' ){
		$post_id = get_queried_object_id();
		if ( function_exists( $length_callback ) ){
			add_filter( 'excerpt_length', $length_callback );
		}
		$output = get_the_excerpt( $post_id );
		$output = apply_filters( 'wptexturize', $output );
		$output = apply_filters( 'convert_chars', $output );
		$output = $output;
		echo esc_html( $output );
	}
endif;

if( !function_exists( 'edumag_pro_excerpt_more' ) ) :
	// read more
	function edumag_pro_excerpt_more( $more ){
		return '...';
	}
	add_filter( 'excerpt_more', 'edumag_pro_excerpt_more' );
endif;

if( !function_exists( 'edumag_pro_trim_content' ) ) :
	/**
	 * custom excerpt function
	 * 
	 * @since EduMag Pro 1.0
	 * @return  no of words to display
	 */
	function edumag_pro_trim_content( $length = 40, $post_obj = null ) {
		global $post;
		if ( is_null( $post_obj ) ) {
			$post_obj = $post;
		}

		$length = absint( $length );
		if ( $length < 1 ) {
			$length = 40;
		}

		$source_content = $post_obj->post_content;
		if ( ! empty( $post_obj->post_excerpt ) ) {
			$source_content = $post_obj->post_excerpt;
		}

		$source_content = preg_replace( '`\[[^\]]*\]`', '', $source_content );
		$trimmed_content = wp_trim_words( $source_content, $length, '...' );

	   return apply_filters( 'edumag_pro_trim_content', $trimmed_content );
	}
endif;

if ( ! function_exists( 'edumag_pro_custom_content_width' ) ) :
	/**
	 * Custom content width.
	 *
	 * @since EduMag Pro 1.0
	 */
	function edumag_pro_custom_content_width() {

		global $content_width;
		$sidebar_position = edumag_pro_layout();
		switch ( $sidebar_position ) {

		  case 'no-sidebar':
		    $content_width = 1170;
		    break;

		  case 'left-sidebar':
		  case 'right-sidebar':
		    $content_width = 819;
		    break;

		  default:
		    break;
		}
		if ( ! is_active_sidebar( 'sidebar-1' ) ) {
			$content_width = 1170;
		}
	}
endif;
add_action( 'template_redirect', 'edumag_pro_custom_content_width' );


if ( ! function_exists( 'edumag_pro_layout' ) ) :
	/**
	 * Check home page layout option
	 *
	 * @since EduMag Pro 1.0
	 *
	 * @return string Theme Palace layout value
	 */
	function edumag_pro_layout() {
		$options = edumag_pro_get_theme_options();

		$sidebar_position = $options['sidebar_position'];
		$sidebar_position = apply_filters( 'edumag_pro_sidebar_position', $sidebar_position );

		// Check if single and static blog page
		if ( is_singular() || is_home() ) {
			if ( is_home() ) {
				$post_sidebar_position = get_post_meta( get_option( 'page_for_posts' ), 'edumag-pro-sidebar-position', true );
			} else {
				$post_sidebar_position = get_post_meta( get_the_id(), 'edumag-pro-sidebar-position', true );
			}
			if ( isset( $post_sidebar_position ) && ! empty( $post_sidebar_position ) ) {
				$sidebar_position = $post_sidebar_position;
			}
		}
		return $sidebar_position;
	}
endif;

if ( ! function_exists( 'edumag_pro_filter_search_query' ) ) :
	/**
	 * add search query 
	 *
	 * @since EduMag Pro 1.0
	 *
	 * @return string search query
	 */

	function edumag_pro_filter_search_query( $query ){
	    global $wp_query;
	    $section 	= isset( $_GET['section'] ) ? $_GET['section'] : '';
	    $taxonomy 	= isset( $_GET['taxonomy'] ) ? $_GET['taxonomy'] : '';
	    $post_type 	= isset( $_GET['post_type'] ) ? $_GET['post_type'] : '';
	    $category  	= isset( $_GET['category'] ) ? $_GET['category'] : '';
	    if ( $wp_query->is_search && !is_admin() && $query->is_main_query() ) {
	    	if ( $section == 'trending' ) :
				if ( $taxonomy == 'category' ) :
			        $query->set( 'category_name', $category );
		        elseif ( $taxonomy != 'category' && $taxonomy != 'demo' ) :
		        	$taxquery = array(
					    array(            
					       'taxonomy' => $taxonomy,
					       'field' => 'slug',
					       'terms' => $category
					    )
					); 
					$query->set( 'tax_query', $taxquery );
			    endif;
	        elseif ( $section == 'search-section' ) :
	        	$query->set( 'post_type', $post_type );
			endif;
	        return $query;
		}
	}
endif;
add_filter( 'pre_get_posts', 'edumag_pro_filter_search_query' );


if ( ! function_exists( 'edumag_pro_footer_sidebar_class' ) ) :
	/**
	 * Count the number of footer sidebars to enable dynamic classes for the footer
	 *
	 * @since EduMag Pro 1.0
	 */
	function edumag_pro_footer_sidebar_class() {
		$data = array();
		$active_id = array();
		$active_sidebar = array();
	   	$count = 0;

	   	if ( is_active_sidebar( 'edumag_pro_footer_sidebar' ) ) {
	   		$active_id[] 		= '1';
	   		$active_sidebar[] 	= 'edumag_pro_footer_sidebar';
	      	$count++;
	   	}

	   	if ( is_active_sidebar( 'edumag_pro_footer_sidebar-2' ) ){
	   		$active_id[] 		= '2';
	   		$active_sidebar[] 	= 'edumag_pro_footer_sidebar-2';
	      	$count++;
		}

	   	if ( is_active_sidebar( 'edumag_pro_footer_sidebar-3' ) ){
	   		$active_id[] 		= '3';
	   		$active_sidebar[] 	= 'edumag_pro_footer_sidebar-3';
	      	$count++;
	   	}

	   	if ( is_active_sidebar( 'edumag_pro_footer_sidebar-4' ) ){
	   		$active_id[] 		= '4';
	   		$active_sidebar[] 	= 'edumag_pro_footer_sidebar-4';
	      	$count++;
	   	}

	   	$class = '';

	   	switch ( $count ) {
        	case '1':
            $class = 'one-column';
            break;
        	case '2':
            $class = 'two-columns';
            break;
        	case '3':
            $class = 'three-columns';
            break;
            case '4':
            $class = 'four-columns';
            break;
	   	}

		$data['active_id'] 		= $active_id;
		$data['active_sidebar'] = $active_sidebar;
		$data['class']     		= $class;

	   	return $data;
	}
endif;


if ( ! function_exists( 'edumag_pro_header_image_meta_option' ) ) :
	/**
	 * Check header image option meta
	 *
	 * @since EduMag Pro 1.0
	 *
	 * @return string Header image meta option
	 */
	function edumag_pro_header_image_meta_option() {
		
		global $post;

		if ( is_object( $post ) ) {
			$post_id = $post->ID;
			$header_image_meta = get_post_meta( $post_id, 'edumag-pro-header-image', true );

			if ( 'enable' == $header_image_meta ) {
				if( has_post_thumbnail( $post_id ) ){

					return get_the_post_thumbnail( $post_id, 'large', $attr = array( 'alt' => esc_attr( get_the_title('$post_id') ) ) );
				} else{
					return '<img src="'.get_template_directory_uri().'/assets/uploads/no-featured-image-1200x400.jpg" alt="'. esc_attr__( 'Banner Image', 'edumag-pro' ) .'"/>';
				}

			}elseif ( '' == $header_image_meta && get_header_image() ) {
				return '<img src="'. esc_url( get_header_image() ) .'" alt="'. esc_attr__( 'Banner Image', 'edumag-pro' ).'"/>';
			} elseif ( 'disable' == $header_image_meta ) {
				return '';
			}
		} else {
			return '<img src="'. esc_url( get_header_image() ) .'" alt="'. esc_attr__( 'Banner Image', 'edumag-pro' ).'"/>';
		}
	}
endif;

if ( ! function_exists( 'edumag_pro_get_post_title' ) ) :
	/**
	 * post/ page titile.
	 *
	 * @since EduMag Pro 1.0
	 */
	function edumag_pro_get_post_title() {
		global $post;

		$post_title = get_the_title( $post );

		if( !empty( $post_title ) ): ?>

		<section id="page-heading" class="page-title">
            <header class="entry-header wow fadeInUp" data-wow-delay="0.3s" data-wow-duration="0.5s">
                <h2 class="entry-title"><?php echo esc_html( $post_title ); ?></h2>
            </header>
        </section><!-- .page-title -->

		<?php
		endif;
	}
endif;
add_action( 'edumag_pro_post_title', 'edumag_pro_get_post_title', 10 );

if ( ! function_exists( 'edumag_pro_get_thumbnail_image' ) ) :
	/**
	 * display post or page thumbnail image
	 *
	 * @since EduMag Pro 1.0
	 *
	 * @return string value
	 */
	function edumag_pro_get_thumbnail_image() {
		if ( post_password_required() || is_attachment() ) {
			return;
		}

		if ( is_singular() ) {
			global $post;
			$post_id = $post->ID;

			$header_image_meta = get_post_meta( $post_id, 'edumag-pro-header-image', true );

			if( 'enable' == $header_image_meta ) return; // retun if thumbnail image is used as a header image.
			the_post_thumbnail( 'large', array( 'alt' => the_title_attribute( 'echo=0' ) ) ); 

		} elseif( is_home() ){ ?>
			<a class="post-thumbnail" href="<?php echo esc_url( get_the_permalink() ); ?>" aria-hidden="true">
			<?php 
				if( has_post_thumbnail() ){
					the_post_thumbnail( 'edumag-pro-blog-images',  array( 'alt' => the_title_attribute( 'echo=0' ) ) );
				} else { 
					echo '<img  src="'. esc_url( get_template_directory_uri() .'/assets/uploads/no-featured-image-175x230.jpg') .'" alt="'. esc_attr( get_the_title() ) .'">';
				}
			?>
			</a>
			<?php

		} elseif( is_archive() || is_search() ){ ?>

			<a class="post-thumbnail" href="<?php echo esc_url( get_the_permalink() ); ?>" aria-hidden="true">
			<?php 
				if( has_post_thumbnail() ){
					the_post_thumbnail( 'edumag-pro-archive-search-image',  array( 'alt' => the_title_attribute( 'echo=0' ) ) );
				}else {
					echo '<img  src="'. esc_url( get_template_directory_uri() .'/assets/uploads/no-featured-image-350x265.jpg') .'" alt="'. esc_attr( get_the_title() ) .'">';
				}
			?>
			</a>
		<?php

		}
		else { ?>
			<a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true">
				<?php the_post_thumbnail( 'post-thumbnail', array( 'alt' => the_title_attribute( 'echo=0' ) ) ); ?>
			</a>
		<?php } 
	}
endif;

if( ! function_exists( 'edumag_pro_get_author_profile' ) ) :
	/*
	 * Function to get author profile
	 */           
	function edumag_pro_get_author_profile(){
		$author_id          = get_the_author_meta( 'ID' );
		$author_description = get_the_author_meta( 'description');
		$author_url         = get_the_author_meta( 'user_url' );
		$author_url         = !empty( $author_url ) ? $author_url : '#' ;
	    ?>
	    <div id="about-author" class="page-section wow fadeInUp" data-wow-delay="0.3s" data-wow-duration="0.5s">
			<header class="entry-header">
				<h2 class="entry-title"><?php esc_html_e( 'About the author', 'edumag-pro' ); ?></h2>
			</header><!-- .entry-header -->
			<div class="entry-content">
				<div class="author-image">
					<?php echo get_avatar( $author_id, 100 );  ?>
				</div><!-- .author-image -->
				<div class="author-content">
					<div class="author-name clear">
				    	<h6><a href="<?php echo esc_url( $author_url ); ?>"><?php the_author_meta('display_name'); ?></a></h6>
				  	</div>
					<?php if( !empty( $author_description ) ) : ?>
						<p><?php echo esc_html( $author_description ); ?></p>
					<?php endif; ?>
				</div><!-- .author-content -->
			</div><!-- .entry-content -->
	    </div><!-- #about-author -->
	    <?php
	}
endif;
add_action( 'edumag_pro_author_profile', 'edumag_pro_get_author_profile' );

if( !function_exists( 'edumag_pro_get_related_posts' ) ) :
	/*
	 * Function to get related posts
	 */           
	function edumag_pro_get_related_posts(){
	    global $post;

	    $options = edumag_pro_get_theme_options(); // get theme options

	    $post_categories = get_the_category( $post->ID ); // get category object
	    $category_ids = array(); // set an empty array

	    if( empty( $post_categories ) ) {
	    	return;
	    }
	    foreach ( $post_categories as $post_category ) {
	      $category_ids[] = $post_category->term_id;
	    }

	    $qargs = array(
	            'posts_per_page'  => 3,
	            'category__in'    => $category_ids,
	            'post__not_in'    => array( $post->ID ),
	            'order'           => 'ASC',
	            'orderby'         => 'rand'
	       	);

	    $related_posts = get_posts( $qargs ); // custom posts

	    if( !empty( $related_posts ) ) : // check if related posts exists
	    ?>
	    <div id="related-posts" class="three-columns page-section clear wow fadeInUp" data-wow-delay="0.3s" data-wow-duration="0.5s">
		    <header class="entry-header">
		        <h2 class="entry-title related_post_title"><?php esc_html_e( 'Related posts', 'edumag-pro' ); ?></h2> 
		    </header>

			<div class="entry-content">
			<?php foreach ( $related_posts as $related_post ) :
		        if ( has_post_thumbnail( $related_post->ID ) ) {
		            $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $related_post->ID ), 'edumag-pro-featured-popular-article' );
		        } else {
		            $img_array = array( get_template_directory_uri() . '/assets/uploads/no-featured-image-450x300.jpg' );
		        }
		        $post_title = get_the_title( $related_post->ID );
		        $post_url   = get_permalink( $related_post->ID );
		        $post_date  = get_the_date( '', $related_post->ID);
		    ?>

				<article id="post-1" class="post has-post-thumbnail hentry">
					<div class="image-wrapper">
						<a class="post-thumbnail" href="<?php echo esc_url( $post_url );?>" aria-hidden="true">
						<img src="<?php echo esc_url( $img_array[0] ); ?>" alt="<?php echo esc_html( $post_title ); ?>">
						</a><!-- end .post-thumbnail -->
					</div><!-- .image-wrapper -->

					<header class="entry-header">
						<h2 class="entry-title"><a href="<?php echo esc_url( $post_url ); ?>"><?php echo esc_html( $post_title ); ?></a></h2>  
						<time datetime="<?php echo date_i18n( esc_html__( 'M d, Y', 'edumag-pro' ), strtotime( get_gmt_from_date( $post_date) ) ); ?>"><?php echo date_i18n( esc_html__( 'M d, Y', 'edumag-pro' ), strtotime( $post_date ) ); ?></time>
					</header><!-- .entry-header -->
				</article><!-- #post-1 -->
			<?php endforeach; ?>

			</div><!-- .entry-content -->
		</div><!-- #related-posts -->
	<?php
		endif;   
	}
endif;
add_action( 'edumag_pro_related_posts', 'edumag_pro_get_related_posts' );

if ( ! function_exists( 'edumag_pro_script_enqueuer' ) ) :
	/**
	 * enque scripts for ajax
	 *
	 * @since EduMag Pro 1.0
	 */
	function edumag_pro_script_enqueuer() {
		$categories_id = get_post_meta( get_the_id(), 'edumag-pro-gallery-template', true );
	   	wp_register_script( 'edumag-pro-ajax', get_template_directory_uri().'/assets/js/ajax.min.js', array( 'jquery' ) );
	   	wp_localize_script( 'edumag-pro-ajax', 'edumag_pro', array( 'ajaxurl' => admin_url( 'admin-ajax.php' ), 'category' => $categories_id ) );        
	   	wp_enqueue_script( 'edumag-pro-ajax' );   
	}
endif;
add_action( 'wp_enqueue_scripts', 'edumag_pro_script_enqueuer' );

add_action("wp_ajax_edumag_pro_ajax_handler", "edumag_pro_ajax_handler");
add_action("wp_ajax_nopriv_edumag_pro_ajax_handler", "edumag_pro_ajax_handler");

if ( ! function_exists( 'edumag_pro_ajax_handler' ) ) :
	/**
	 * ajax handler
	 *
	 * @since EduMag Pro 1.0
	 */
	function edumag_pro_ajax_handler(){
		$options = edumag_pro_get_theme_options();
		$posts_per_page = get_option( 'posts_per_page', 12 );

	    $page = isset( $_POST['pageNumber'] ) ? $_POST['pageNumber'] : 1;
	    $gallery_ids = ! empty( $_POST['category'] ) ? $_POST['category'] : array();

	    header("Content-Type: text/html");

	    $args = array(
	        'post_type' 		=> 'post',
	        'posts_per_page' 	=> absint( $posts_per_page ),
	        'category__in'      => $gallery_ids,
	        'paged'    			=> $page,
	    );

        $gallery_posts = get_posts( $args );

        foreach ( $gallery_posts as $key => $gallery_post ) {
           	$gallery_post_id = $gallery_post->ID;

			$image_array_small = array();
			if( has_post_thumbnail( $gallery_post_id ) ){
				$image_array_small = wp_get_attachment_image_src( get_post_thumbnail_id( $gallery_post_id ), 'edumag-pro-gallery-image' );
				$image_array_large = wp_get_attachment_image_src( get_post_thumbnail_id( $gallery_post_id ), 'large' );
			} else {
				$image_array_small[0] = get_template_directory_uri().'/assets/uploads/no-featured-image-250x250.jpg';
				$image_array_large[0] = get_template_directory_uri().'/assets/uploads/no-featured-image-250x250.jpg';
			}
			$post_title = get_the_title( $gallery_post_id );
			$post_url = get_the_permalink( $gallery_post_id ); 
			$post_categories = get_the_category( $gallery_post_id );

			$post_category_list = '';
			foreach ( $post_categories as $key => $post_category ) {
				$post_category_list .= $post_category->slug . ' ';
			}
     	?>
            <div class="portfolio-item <?php echo esc_attr( $post_category_list );?>">
                <div class="image-wrapper">
                  <img src="<?php echo esc_url( $image_array_small[0] ); ?>" alt="<?php echo esc_html( $post_title ); ?>">
                  <div class="blue-overlay"></div>             
                </div><!-- .image-wrapper -->
                <div class="hover-buttons">
                  	<div class="popup-image">
                    	<a href="<?php echo esc_url( $image_array_large[0] ); ?>" class="popup">
	                      	<i class="fa fa-eye"></i>
	                      	<img src="<?php echo esc_url( $image_array_large[0] ); ?>" alt="<?php echo esc_html( $post_title ); ?>">
                    	</a>
                  	</div><!-- .popup-image -->

                	<div class="portfolio-link">
                    	<a href="<?php echo esc_url( $post_url ); ?>"><i class="fa fa-heart"></i></a>
                	</div><!-- .portfolio-link -->
                </div><!-- .hover-buttons -->
          	</div><!-- .portfolio-item -->
        <?php }
	    die();
	}
endif;


