<?php
/**
 * Featured category section
 *
 * This is the template for the content of Featured category section
 *
 * @package Theme Palace
 * @subpackage EduMag Pro
 * @since EduMag Pro 1.0
 */
if ( ! function_exists( 'edumag_pro_add_featured_category_section' ) ) :
  /**
   * Add Featured category section
   *
   *@since EduMag Pro 1.0
   */
  function edumag_pro_add_featured_category_section() {

    // Check if Featured category is enabled on frontpage
    $featured_category_enable = apply_filters( 'edumag_pro_section_status', true, 'featured_category_enable' );
    if ( true !== $featured_category_enable ) {
      return false;
    }

    // Get Featured category section details
    $section_details = array();
    $section_details = apply_filters( 'edumag_pro_filter_featured_category_section_details', $section_details );
    if ( empty( $section_details ) ) {
      return;
    }

    // Render Featured category section now.
    edumag_pro_render_featured_category_section( $section_details );
  }
endif;
add_action( 'edumag_pro_primary_content', 'edumag_pro_add_featured_category_section', 10 );


if ( ! function_exists( 'edumag_pro_get_featured_category_section_details' ) ) :
  /**
   * Featured category section details.
   *
   * @since EduMag Pro 1.0
   * @param array $input Featured category section details.
   */
  function edumag_pro_get_featured_category_section_details( $input ) {
    $options = edumag_pro_get_theme_options();

    // Featured category type
    $featured_category_content_type = $options['featured_category_content_type'];

    $content = array();
    switch ( $featured_category_content_type ) {
        case 'demo':
            $demo_title = array(
                esc_html__( 'UK Students Continuing to Look Overseas', 'edumag-pro'),
                esc_html__( 'Unleash great knowledge about student life', 'edumag-pro'),
                esc_html__( 'Prevent your stress while studying', 'edumag-pro'),
                esc_html__( 'Find the best college that suits your career.', 'edumag-pro')
            );

            $demo_category = array(
                esc_html__( 'STUDY', 'edumag-pro' ),
                esc_html__( 'CAREERS', 'edumag-pro' ),
                esc_html__( 'HEALTH', 'edumag-pro' ),
                esc_html__( 'COLLEGE', 'edumag-pro' ),
            );

            $image_array = array( 'featured-01.jpg', 'featured-02.jpg', 'featured-03.jpg', 'featured-04.jpg' );

            for ( $i=0; $i<4; $i++ ) {
                $content[$i]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/'. $image_array[$i];
                $content[$i]['url']          = '#';
                $content[$i]['title']        = $demo_title[$i];
                $content[$i]['cat_title']    = $demo_category[$i];
                $content[$i]['cat_url']      = '#';
            }
        break;

        case 'posts':
            $posts_ids = array(); // set empty array of posts id
            for( $i=1; $i<=4; $i++ ){
                if( !empty( $options['featured_category_content_posts_'. $i ] ) ){
                    $post_id    = ! empty ( $options['featured_category_content_posts_' . $i] ) ? absint( $options['featured_category_content_posts_' . $i] ) : '';
                    $posts_ids  = array_merge( $posts_ids, array( $post_id ) );
                }
            }
            // Bail if no valid pages are selected.
            if ( empty( $posts_ids ) ) {
                return $input;
            }
            $args = array(
                'post_type'      => 'post',
                'post__in'       => $posts_ids,
                'orderby'        => 'post__in',
                'posts_per_page' => 4,
            );

            $posts = get_posts( $args ); // get posts 

            $i = 1;
            foreach ( $posts as $post ) {

                $post_id   = $post->ID;
                $img_array = null;

                if ( has_post_thumbnail( $post_id ) ) {
                    $image_size = ( 1 == $i ) ? 'large' : 'edumag-pro-featured-popular-article';
                    $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), $image_size );
                } else {
                    $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-450x300.jpg';
                }

                if ( isset( $img_array ) ) {
                  $content[$i]['img_array'] = $img_array;
                }

                $content[$i]['url']        = get_permalink( $post_id );
                $content[$i]['title']      = get_the_title( $post_id );
                $content[$i]['categories'] = get_the_category( $post_id );
            $i++;
            }
        break;

        case 'category':
            // Fetch posts.
            for( $i=1; $i<=4; $i++ ){
                $category_id = !empty( $options['featured_category_content_category_'. $i ] ) ? $options['featured_category_content_category_'. $i ] : '';
                
                if( !empty( $category_id ) ){
                    $args = array( 
                        'cat'                 => absint( $category_id ),
                        'posts_per_page'      => 1,
                        'ignore_sticky_posts' => true
                    );

                    $category_posts = get_posts( $args );

                    if( !empty( $category_posts ) ){
                        $post_id   = $category_posts[0]->ID;
                        $img_array = array();

                        if ( has_post_thumbnail( $post_id ) ) {
                            $image_size = ( 1 === $i ) ? 'large' : 'edumag-pro-featured-popular-article';
                            $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), $image_size );
                        }  else {
                            $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-450x300.jpg';
                        }   

                        $content[$i]['img_array']    = $img_array;
                        $content[$i]['url']          = get_permalink( $post_id );
                        $content[$i]['title']        = get_the_title( $post_id );
                        $content[$i]['cat_title']    = get_cat_name( $category_id );
                        $content[$i]['cat_url']      = get_category_link( $category_id );
                    }
                }
            }
        break;

        default:
        break;
    }
                                                                                                               
    if ( !empty( $content ) ) {
      $input = $content;
    }
    return $input;
  }
endif;
// Featured category section content details.
add_filter( 'edumag_pro_filter_featured_category_section_details', 'edumag_pro_get_featured_category_section_details' );


if ( ! function_exists( 'edumag_pro_render_featured_category_section' ) ) :
  /**
   * Start Featured category section
   *
   * @return string Featured category content
   * @since EduMag Pro 1.0
   *
   */
   function edumag_pro_render_featured_category_section( $content_details ) {
    ?>
    <section id="featured-category" class="page-section two-columns">
        <div class="shadow-overlay"></div>
        <div class="container">
        <?php   
            if ( empty( $content_details ) ) return;
            $options = edumag_pro_get_theme_options(); // get theme options
            $count = count( $content_details );
        ?>
            <div class="column-wrapper">
                <?php 
                    $index = 1;
                    foreach ( $content_details as $content_detail ) :

                        $cat_html = array();
                        if( 'posts' == $options['featured_category_content_type'] ){
                            $categories = $content_detail['categories'];
                            $cat_count = 1;
                            foreach ($categories as $key => $category) {
                               $cat_html[$cat_count] = '<a class="category-name" href="'. esc_url( get_category_link( $category->term_id) ) .'">'. esc_html( $category->name ).'</a>';
                               if( $cat_count == 2  ) break;
                               $cat_count++; 
                            }
                        } else{
                            $cat_html[0] = '<a class="category-name" href="'. esc_url( $content_detail['cat_url'] ) .'">'. esc_html( $content_detail['cat_title'] ) .'</a>';
                        }

                        if( $index == 1 ){
                        ?>
                            <div class="featured-post-image" style="background-image: url('<?php echo esc_url( $content_detail['img_array'][0] ); ?>">
                            </div><!-- .featured-post-image -->

                            <div class="featured-post-title">
                                <?php foreach( $cat_html as $value ) echo wp_kses_post( $value ); ?>
                                <div class="title-bottom-line"></div>
                                <h2 class="wow fadeInUp" data-wow-delay="0.3s" data-wow-duration="0.3s"><a href="<?php echo esc_url( $content_detail['url'] ); ?>"><?php echo esc_html( $content_detail['title']); ?></a></h2>
                            </div><!-- .featured-post-title -->

                    <?php 
                        } else{ ?>
                            <div class="featured-category-wrapper" style="background-image: url('<?php echo esc_url( $content_detail['img_array'][0] ); ?>')">

                                <div class="black-overlay"></div>
                                <div class="featured-category-contents">
                                    <?php foreach( $cat_html as $value ) echo wp_kses_post( $value ); ?>
                                    <h4><a href="<?php echo esc_url( $content_detail['url'] ); ?>"><?php echo esc_html( $content_detail['title']); ?></a></h4>
                                </div><!--.featured-category-contents-->
                            </div><!--.featured-category-wrapper-->

                    <?php }

                        $index++; 
                        if( $index == 2 && $count > 1 ){
                            echo '</div><!--.column-wrapper-->';
                            echo '<div class="column-wrapper">';
                        }

                endforeach; ?>
            </div><!--.column-wrapper-->
        </div><!--.container-->      
    </section><!-- #featured-category -->
    <?php 
    }
endif;