<?php
/**
 * Gallery Widget
 *
 * @package Theme Palace
 * @subpackage EduMag Pro
 * @since EduMag Pro 1.0
 */

if ( ! class_exists( 'Edumag_Pro_Gallery_Widget' ) ) :

/**
 * Gallery Class
 *
 * @since 1.0
 *
 * @see WP_Widget
 */
class Edumag_Pro_Gallery_Widget extends WP_Widget {

	/**
	 * Sets up a new gallery widget instance.
	 *
	 * @since 1.0
	 * @access public
	 */
	public function __construct() {
		$widget_ops = array(
			'classname'                   => 'widget_gallery',
			'description'                 => esc_html__( 'Shows Your site&#8217;s gallery post format images.','edumag-pro' ),
			'customize_selective_refresh' => true,
		);
		parent::__construct( 'tp-widget-gallery', esc_html__( 'TP: Gallery Widget', 'edumag-pro' ), $widget_ops );
		$this->alt_option_name = 'widget_gallery';
	}

	/**
	 * Outputs the content for the gallery widget instance.
	 *
	 * @since 1.0
	 * @access public
	 *
	 * @param array $args     Display arguments including 'before_title', 'after_title',
	 *                        'before_widget', and 'after_widget'.
	 * @param array $instance Settings for the gallery widget instance.
	 */
	public function widget( $args, $instance ) {
		$post_id = isset( $instance['post_id'] ) ? $instance['post_id'] : 0;
		if ( ! has_post_format( 'gallery', $post_id ) ) return;

		$attachments    = get_post_gallery( $post_id, false );

		if( empty($attachments['ids'] ) ) return;
		
		$attachment_ids = explode( ',', $attachments['ids'] );

		$column_layout = !empty( $instance['column_layout'] ) ? $instance['column_layout'] : 'three-columns';
		$number = !empty( $instance['number'] ) ? $instance['number'] : 9;

		if ( empty( $attachments ) ) return;

		if ( ! isset( $args['widget_id'] ) )
		$args['widget_id'] = $this->id;

		$title             = ( !empty( $instance['title'] ) ) ? $instance['title'] : '';

		/** This filter is documented in wp-includes/widgets/class-wp-widget-pages.php */
		$title             = apply_filters( 'widget_title', $title, $instance, $this->id_base );

		echo $args['before_widget'];
		if ( ! empty( $title ) ) {
			echo $args['before_title'] . esc_html( $title ) . $args['after_title'];
		}
		?>
        <ul class="<?php echo esc_attr( $column_layout ); ?>">

        	<?php 
	        	$index = 1;
	        	$count_gallery = count( $attachment_ids ); 
	        	foreach ( $attachment_ids as $attachment_id ) :
	        ?>
            	<li><?php echo wp_get_attachment_link( $attachment_id, 'edumag-pro-featured-popular-article', true ); ?></li>        
            <?php 
            	if( ( $count_gallery >= $number ) && ( $index == $number ) ) break;
            	$index++;
            	endforeach;
            ?>
        </ul>
		<?php 
		echo $args['after_widget'];
	}

	/**
	 * Handles updating settings for the gallery widget instance.
	 *
	 * @since 1.0
	 * @access public
	 *
	 * @param array $new_instance New settings for this instance as input by the user via
	 *                            WP_Widget::form().
	 * @param array $old_instance Old settings for this instance.
	 * @return array Updated settings to save.
	 */
	public function update( $new_instance, $old_instance ) {
		$columns = array(
			'one-column'    => esc_html__( 'One Column', 'edumag-pro' ),
			'two-columns'   => esc_html__( 'Two Columns', 'edumag-pro' ),
			'three-columns' => esc_html__( 'Three Columns', 'edumag-pro' ),
			'four-columns'  => esc_html__( 'Four Columns', 'edumag-pro' ),
			'five-columns'  => esc_html__( 'Five Columns', 'edumag-pro' ),
		);

		$instance            = $old_instance;
		$instance['title']   = sanitize_text_field( $new_instance['title'] );
		$instance['post_id'] = absint( $new_instance['post_id'] );
		$instance['column_layout'] = array_key_exists( $new_instance['column_layout'], $columns ) ? $new_instance['column_layout'] : '';
		$instance['number']  = absint( $new_instance['number'] );
		return $instance;
	}

	/**
	 * Outputs the settings form for the gallery widget.
	 *
	 * @since 1.0
	 * @access public
	 *
	 * @param array $instance Current settings.
	 */
	public function form( $instance ) {

		$defaults = array( 'title' => '', 'post_id' => 0, 'column_layout' => 'three-columns', 'number' => 6  );
		$instance = wp_parse_args ( $instance , $defaults );
		extract( $instance );

		$gallery_posts = get_posts( array(
			'posts_per_page'	=>	-1,
			'tax_query'		=>	array(
				array(
					'taxonomy'	=>	'post_format',
					'field'		=>	'slug',
					'terms'		=>	array( 'post-format-gallery' )
				)
			)
		) );

		$columns = array(
			'one-column'    => esc_html__( 'One Column', 'edumag-pro' ),
			'two-columns'   => esc_html__( 'Two Columns', 'edumag-pro' ),
			'three-columns' => esc_html__( 'Three Columns', 'edumag-pro' ),
			'four-columns'  => esc_html__( 'Four Columns', 'edumag-pro' ),
			'five-columns'  => esc_html__( 'Five Columns', 'edumag-pro' ),
		);

		if ( empty( $gallery_posts ) ) {
			echo '<p class="description">'. sprintf( esc_html__( 'No galleries have been created yet. <a href="%1$s">%2$s</a>.', 'edumag-pro' ), admin_url( 'post-new.php' ),esc_html__( 'Create Some','edumag-pro' ) ) . '</p>';
			return;
		}
		?>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'edumag-pro' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'post_id' ) ); ?>"><?php esc_html_e( 'Select Gallery:', 'edumag-pro' ); ?></label>
			<select name="<?php echo esc_attr( $this->get_field_name( 'post_id' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'post_id' ) ); ?>" class="widefat">
				<?php foreach ( $gallery_posts as $gallery_post ) {
					echo '<option value="' . esc_attr( $gallery_post->ID ) . '"' . selected( $post_id, $gallery_post->ID ) .'>' . esc_html( $gallery_post->post_title ). '</option>';
				} ?>
			</select>
			<span><b><?php esc_html_e( 'Create gallery in selected post', 'edumag-pro' ); ?></b></span>
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'column_layout' ) ); ?>"><?php esc_html_e( 'Columns Layout:', 'edumag-pro' ); ?></label>
			<select name="<?php echo esc_attr( $this->get_field_name( 'column_layout' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'column_layout' ) ); ?>" class="widefat">
				<?php foreach ( $columns as $key => $column ) {
					echo '<option value="' . esc_attr( $key ) . '"' . selected( $column_layout, $key, false ) .'>' . esc_html( $column ). '</option>';
				} ?>
			</select>
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>"><b><?php esc_html_e( 'Number of Gallery Image:', 'edumag-pro' ); ?></b></label>
			<input type="number" id="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'number' ) ); ?>" value="<?php echo absint( $instance['number'] ); ?>" class="small-text" min="1" /><br>
			<i><?php esc_html_e( 'Info: Works only when number of gallery images in selected post is greater than value in this field.', 'edumag-pro' ); ?></i>
		</p>
		<?php
	}
}
endif;
/*
 * Function to register counter widget
 *
 * Since 1.0
 */
function edumag_pro_register_gallery_widget(){
	register_widget( 'Edumag_Pro_Gallery_Widget' );
}
add_action( 'widgets_init', 'edumag_pro_register_gallery_widget' );