<?php
/**
 * Posts Slider Widget
 *
 * @package Theme Palace
 * @subpackage EduMag Pro
 * @since EduMag Pro 1.0
 */

if ( ! class_exists( 'Edumag_Pro_Custom_Post_Slider_Widget' ) ) :
	/**
	 * Social Media class.
	 *
	 * @since EduMag Pro 1.0
	 */
	class Edumag_Pro_Custom_Post_Slider_Widget extends WP_Widget {
		/**
		 * Sets up the widgets name etc
		 */
		public function __construct() {
			$widget_ops = array(
				'classname'   => 'widget_post_slider',
				'description' => esc_html__( 'Enter post id to use it as a slider', 'edumag-pro' ),
			);
			parent::__construct( 'post-slides',esc_html__('TP : Post Slider','edumag-pro'), $widget_ops );
		}

		/**
		 * Outputs the content of the widget
		 *
		 * @param array $args
		 * @param array $instance
		 */
		public function widget( $args, $instance ) {
			// outputs the content of the widget
			if ( ! isset( $args['widget_id'] ) ) {
				$args['widget_id'] = $this->id;
			}
	
			$title                 =  !empty( $instance['title'] ) ? $instance['title'] : '';
			$number                =  isset( $instance['number'] ) ? absint( $instance['number'] ) : 3;
			$enable_pager_control  =  !empty( $instance['enable_pager_control'] ) ? 'true' : 'false';
			$enable_pause_on_hover =  !empty( $instance['enable_pause_on_hover'] ) ? 'true' : 'false';
			$enable_arrow_controls =  !empty( $instance['enable_arrow_controls'] ) ? 'true' : 'false';

			$slider_control = '{"slidesToShow": 1, "slidesToScroll": 1, "pauseOnHover":'. esc_attr( $enable_pause_on_hover  ) .', "speed": "800", "dots":'. esc_attr( $enable_pager_control ) .', "arrows": '. esc_attr( $enable_arrow_controls ) .', "infinite": true, "autoplay": true}';

			$posts_ids = array();
			for( $i=1; $i<=$number; $i++ ){
				if( !empty( $instance['post-id-'. $i] ) )
				$posts_ids = array_merge( $posts_ids, array( $instance['post-id-'. $i] ) );
			}

			$post_args = array(
				'post_type'      => 'post',
				'post__in'       => $posts_ids,
				'orderby'		 => 'post__in',
				'posts_per_page' => absint( $number )
			);

			$custom_posts = get_posts( $post_args );

			echo $args['before_widget'];
				if ( ! empty( $title ) ) {
					echo $args['before_title'] . esc_html( $title ) . $args['after_title'];
				}
			?>
	            <div class="widget-wrap">
	            <?php if( !empty( $custom_posts ) ){ ?>
	                <div class="regular" data-effect="cubic-bezier(0.680, 0, 0.265, 1)" data-slick='<?php echo $slider_control; ?>'>
	                	<?php foreach( $custom_posts as $custom_post ) :
	                	$post_id = $custom_post->ID; 

	                	if ( has_post_thumbnail( $post_id ) ) {
                            $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'edumag-pro-featured-popular-article' );
                    	} else {
                            $img_array = array ( get_template_directory_uri() . '/assets/uploads/no-featured-image-450x300.jpg' );
                    	}
						$title   = get_the_title( $post_id );
						$category_object = get_the_category( $post_id );

						foreach ( $category_object as $category ) {
							$category_url = get_category_link( $category->term_id );
							$category_name = $category->name;
							break;
						}
                    	?>
	                    <div class="slider-item">
	                        <a href="<?php echo esc_url( get_permalink( $post_id ) ); ?>"><img src="<?php echo esc_url( $img_array[0] ); ?>" alt="<?php echo esc_attr( $title ); ?>">
	                        <div class="black-overlay"></div></a>
	                        
	                        <div class="slider-title">
	                         	<a href="<?php echo esc_url( $category_url ); ?>" class="category-name"><?php echo esc_html( $category_name ); ?></a>
	                         	<h4><a href="<?php echo esc_url( get_permalink( $post_id ) ); ?>"><?php echo esc_html( $title ); ?></a></h4>
	                        </div><!--.slider-title-->
	                    </div><!-- .slider-item -->
	                    <?php endforeach; ?>

	                </div><!-- .regular-->
	            </div><!-- .widget-wrap -->
				<?php
			echo $args['after_widget'];
			}
		}

		/**
		 * Outputs the options form on admin
		 *
		 * @param array $instance The widget options
		 */
		public function form( $instance ) {
			$title                 = isset( $instance['title'] ) ? ( $instance['title'] ) : '';
			$number                = isset( $instance['number'] ) ? absint( $instance['number'] ) : 3;
			$enable_arrow_controls = isset( $instance['enable_arrow_controls'] ) ? $instance['enable_arrow_controls'] : false;
			$enable_pause_on_hover = isset( $instance['enable_pause_on_hover'] ) ? $instance['enable_pause_on_hover'] : false;
			$enable_pager_control  = isset( $instance['enable_pager_control'] ) ? $instance['enable_pager_control'] : false;

		   ?>

		    <p>
			   <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'edumag-pro' ); ?></label>
			   <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		    </p>

		    <p>
		   		<label for="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>"><?php esc_html_e( 'Number of posts:', 'edumag-pro' ); ?></label>
		   		<input class="tiny-text" id="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'number' ) ); ?>" type="number" step="1" min="1" max="6" value="<?php echo absint( $number ); ?>" size="3" />
		    </p>
		    <b><?php esc_html_e('Post Slider','edumag-pro'); ?></b>
		    <?php for( $i=1; $i<=$number; $i++ ):
		    	$post_id = isset( $instance['post-id-'. $i] ) ? $instance['post-id-'. $i] : 0; ?>
		    <p>
		   		<label for="<?php echo esc_attr( $this->get_field_id( 'post-id-'. $i ) ); ?>"><?php printf( esc_html__( 'Enter Post ID #%s:', 'edumag-pro' ), $i ); ?></label>
		   		<input class="wide-fat" id="<?php echo esc_attr( $this->get_field_id( 'post-id-'. $i ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'post-id-'. $i ) ); ?>" type="number" step="1" min="1"  value="<?php echo absint( $post_id ); ?>" size="5" />
			</p>
			<?php endfor; ?>
			<i><b><?php esc_html_e('Slider controls','edumag-pro'); ?></b></i>
			<p>
		      	<label for="<?php echo esc_attr( $this->get_field_id( 'enable_arrow_controls' ) ); ?>"><?php esc_html_e( 'Enable Arrow Controls', 'edumag-pro' ); ?>:</label>
		      	<input type="checkbox" id="<?php echo esc_attr( $this->get_field_id( 'enable_arrow_controls' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'enable_arrow_controls' ) ); ?>"  <?php checked( $enable_arrow_controls, true ); ?> />
		    </p>

		    <p>
		      	<label for="<?php echo esc_attr( $this->get_field_id( 'enable_pause_on_hover' ) ); ?>"><?php esc_html_e( 'Enable Pause on Hover', 'edumag-pro' ); ?>:</label>
		      	<input type="checkbox" id="<?php echo esc_attr( $this->get_field_id( 'enable_pause_on_hover' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'enable_pause_on_hover' ) ); ?>"  <?php checked( $enable_pause_on_hover, true ); ?> />
		    </p>

		    <p>
		      	<label for="<?php echo esc_attr( $this->get_field_id( 'enable_pager_control' ) ); ?>"><?php esc_html_e( 'Enable Pager control', 'edumag-pro' ); ?>:</label>
		      	<input type="checkbox" id="<?php echo esc_attr( $this->get_field_id( 'enable_pager_control' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'enable_pager_control' ) ); ?>"  <?php checked( $enable_pager_control, true ); ?> />
		    </p>

		   <?php
		}

		/**
		* Processing widget options on save
		*
		* @param array $new_instance The new options
		* @param array $old_instance The previous options
		*/
		public function update( $new_instance, $old_instance ) {
			// processes widget options to be saved
			$instance                          = $old_instance;
			$instance['title']                 = sanitize_text_field( $new_instance['title'] );
			$instance['number']                = isset( $new_instance['number'] ) ? absint( $new_instance['number'] ) : 3;
			for ( $i =1; $i <= $instance['number']; $i++ ) {
				$instance['post-id-'. $i] = absint( $new_instance['post-id-'.$i] );
			}
			$instance['enable_arrow_controls'] =  isset( $new_instance['enable_arrow_controls'] ) ? ( bool )$new_instance['enable_arrow_controls'] : false;
			$instance['enable_pause_on_hover'] =  isset( $new_instance['enable_pause_on_hover'] ) ? ( bool )$new_instance['enable_pause_on_hover'] : false;
			$instance['enable_pager_control']  =  isset( $new_instance['enable_pager_control'] ) ? ( bool )$new_instance['enable_pager_control'] : false;
			return $instance;
		}
	}
endif;

function edumag_pro_register_custom_post_slider_widget() {
	register_widget( 'Edumag_Pro_Custom_Post_Slider_Widget' );
}
add_action( 'widgets_init', 'edumag_pro_register_custom_post_slider_widget' );